is_dims: helper to check if a string looks like a cell

View source: R/utils.R

is_dimsR Documentation

helper to check if a string looks like a cell

Description

helper to check if a string looks like a cell

Usage

is_dims(x)

Arguments

x

a string


openxlsx2 documentation built on May 25, 2026, 5:10 p.m.