temp_xlsx: helper function to create temporary directory for testing...

View source: R/utils.R

temp_xlsxR Documentation

helper function to create temporary directory for testing purpose

Description

helper function to create temporary directory for testing purpose

Usage

temp_xlsx(name = "temp_xlsx", macros = FALSE)

Arguments

name

for the temp file

macros

logical if the file extension is xlsm or xlsx


openxlsx2 documentation built on Feb. 21, 2026, 9:07 a.m.