- b
Logical, whether the font should be bold.
- charset
Character, the character set to be used. The list of valid IDs can be found in the Details section of fmt_txt().
- color
A wb_color(), the color of the font. Default is "FF000000".
- condense
Logical, whether the font should be condensed.
- extend
Logical, whether the font should be extended.
- family
Character, the font family. Default is "2" (modern). "0" (auto), "1" (roman), "2" (swiss), "3" (modern), "4" (script), "5" (decorative). # 6-14 unused
- i
Logical, whether the font should be italic.
- name
Character, the name of the font. Default is "Aptos Narrow".
- outline
Logical, whether the font should have an outline.
- scheme
Character, the font scheme. Valid values are "minor", "major", "none", or "". Default is "". If set to "minor" or "major", the spreadsheet software will pick the font from the active theme, using name only as a fallback.
- shadow
Logical, whether the font should have a shadow.
- strike
Logical, whether the font should have a strikethrough.
- sz
Character, the size of the font. Default is "11".
- u
Character, the underline style. Valid values are "single", "double", "singleAccounting", "doubleAccounting", "none".
- vert_align
Character, the vertical alignment of the font. Valid values are "baseline", "superscript", "subscript".
- ...
Additional arguments passed to other methods.